@@ -39,20 +39,20 @@
 #' \dontrun{
 #' # Download data on all bills
 #' x <- bills()
-#' 
+#'
 #' # Download data on all bill amendments
 #' x <- bills(amendments = TRUE)
-#' 
+#'
 #' # Download data on a specific bills
 #' x <- bills(1719)
-#' 
+#'
 #' # Download data on all bills introduced after a given date
 #' x <- bills(start_date = "2016-01-01")
 #' }
-#' 
+#'
 bills <- function(ID = NULL, amendments = FALSE, start_date = "1900-01-01",
                   end_date = Sys.Date(), extra_args = NULL, tidy = TRUE,
-                  tidy_style = "snake_case", verbose = TRUE) {
+                  tidy_style = "snake", verbose = TRUE) {
   dates <- paste0(
     "&_properties=date&max-date=",
     as.Date(end_date),
@@ -81,8 +81,7 @@ bills <- function(ID = NULL, amendments = FALSE, start_date = "1900-01-01",
 
   query <- paste0(
     baseurl, amend_query,
-    dates, id_query, extra_args,
-    "&_pageSize=100&_page="
+    dates, id_query, extra_args
   )
 
   df <- loop_query(query, jpage, verbose) # in utils-loop.R
