@@ -9,16 +9,7 @@
 #' @param extra_args Additional parameters to pass to API.
 #' Defaults to `NULL`.
 #'
-#' @param tidy Logical parameter. If TRUE, fixes the variable names in the
-#' tibble to remove special characters and superfluous text, and converts
-#' the variable names to a consistent style. Defaults to `TRUE`.
-#'
-#' @param tidy_style The style to convert variable names to, if
-#' `tidy = TRUE`. Accepts one of `'snake_case'`, `'camelCase'`
-#' and `'period.case'`. Defaults to `'snake_case'`.
-#'
-#' @param verbose If `TRUE`, returns data to console on the progress of
-#' the API request. Defaults to `FALSE`.
+#' @inheritParams all_answered_questions
 #'
 #' @return A tibble with the dates of divisions in the House of Commons.
 #' @export
@@ -27,9 +18,9 @@
 #' # all commons divisions on 19 April 2017
 #' x <- commons_division_date("2017-04-19")
 #' }
-#' 
+#'
 commons_division_date <- function(date = NULL, extra_args = NULL, tidy = TRUE,
-                                  tidy_style = "snake_case", verbose = TRUE) {
+                                  tidy_style = "snake", verbose = TRUE) {
   if (is.null(date) == TRUE) {
     stop("Please include a date.", call. = FALSE)
   } else {
@@ -49,8 +40,7 @@ commons_division_date <- function(date = NULL, extra_args = NULL, tidy = TRUE,
     jpage <- floor(divis$result$totalResults / 100)
 
     query <- paste0(
-      baseurl, ".json?", date, extra_args,
-      "&_pageSize=100&_page="
+      baseurl, ".json?", date, extra_args
     )
 
     df <- loop_query(query, jpage, verbose) # in utils-loop.R
